# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.sheet
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing
from .formula_token import FormulaToken as FormulaToken_bd1c0bf8


class FormulaOpCodeMapEntry(object):
    """
    Struct Class

    contains a mapping from a formula name (function name, operator, ...) to the OpCode used by the formula compiler.

    See Also:
        `API FormulaOpCodeMapEntry <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1sheet_1_1FormulaOpCodeMapEntry.html>`_
    """
    typeName: Literal['com.sun.star.sheet.FormulaOpCodeMapEntry']

    def __init__(self, Name: typing.Optional[str] = ..., Token: typing.Optional[FormulaToken_bd1c0bf8] = ...) -> None:
        """
        Constructor

        Arguments:
            Name (str, optional): Name value.
            Token (FormulaToken, optional): Token value.
        """


    @property
    def Name(self) -> str:
        """
        The function name, or operator.
        """


    @property
    def Token(self) -> FormulaToken_bd1c0bf8:
        """
        The corresponding mapping.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.awt
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .font_descriptor import FontDescriptor as FontDescriptor_bc110c0a
    from .simple_font_metric import SimpleFontMetric as SimpleFontMetric_d53c0cb9

class XFont(XInterface_8f010a43):
    """
    describes a font on a specific device.
    
    All values are in pixels within this device.

    See Also:
        `API XFont <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XFont.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.awt.XFont']

    def getCharWidth(self, c: str) -> int:
        """
        returns the width of the specified character.
        """
    def getCharWidths(self, nFirst: str, nLast: str) -> 'typing.Tuple[int, ...]':
        """
        returns the widths of the specified characters.
        """
    def getFontDescriptor(self) -> 'FontDescriptor_bc110c0a':
        """
        returns the description of the font.
        
        The unit of measurement is pixels for the device.
        """
    def getFontMetric(self) -> 'SimpleFontMetric_d53c0cb9':
        """
        returns additional information about the font.
        """
    def getKernPairs(self, Chars1: 'typing.Tuple[str, ...]', Chars2: 'typing.Tuple[str, ...]', Kerns: 'typing.Tuple[int, ...]') -> None:
        """
        queries the kerning pair table.

        * ``Chars1`` is an out direction argument.
        * ``Chars2`` is an out direction argument.
        * ``Kerns`` is an out direction argument.
        """
    def getStringWidth(self, str: str) -> int:
        """
        returns the string width.
        """
    def getStringWidthArray(self, str: str, aDXArray: 'typing.Tuple[int, ...]') -> int:
        """
        returns the string and the character widths.

        * ``aDXArray`` is an out direction argument.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing
from .x_content_provider import XContentProvider as XContentProvider_d4150cc0


class ContentProviderInfo(object):
    """
    Struct Class

    A structure for content provider information.

    See Also:
        `API ContentProviderInfo <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1ucb_1_1ContentProviderInfo.html>`_
    """
    typeName: Literal['com.sun.star.ucb.ContentProviderInfo']

    def __init__(self, ContentProvider: typing.Optional[XContentProvider_d4150cc0] = ..., Scheme: typing.Optional[str] = ...) -> None:
        """
        Constructor

        Arguments:
            ContentProvider (XContentProvider, optional): ContentProvider value.
            Scheme (str, optional): Scheme value.
        """


    @property
    def ContentProvider(self) -> XContentProvider_d4150cc0:
        """
        The content provider.
        """


    @property
    def Scheme(self) -> str:
        """
        The scheme the Provider is registered for.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.util
from typing_extensions import Literal
from .x_modifiable import XModifiable as XModifiable_a4f60b0a

class XModifiable2(XModifiable_a4f60b0a):
    """
    allows to control modifiable state change.
    
    This interface allows to prevent changing of the modified state of the object. It is introduced for performance optimizations, to allow to prevent unnecessary updates, for example while importing a document. Please use this interface very carefully.

    See Also:
        `API XModifiable2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1util_1_1XModifiable2.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.util.XModifiable2']

    def disableSetModified(self) -> bool:
        """
        disable possibility to change modified state of the document
        """
    def enableSetModified(self) -> bool:
        """
        enable possibility to change modified state of the document
        """
    def isSetModifiedEnabled(self) -> bool:
        """
        allows to detect whether the modified state change is enabled
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.accessibility
from typing_extensions import Literal
import typing
from .x_accessible_component import XAccessibleComponent as XAccessibleComponent_b2f21269
if typing.TYPE_CHECKING:
    from ..awt.x_font import XFont as XFont_5f480843

class XAccessibleExtendedComponent(XAccessibleComponent_b2f21269):
    """
    The XAccessibleExtendedComponent interface contains additional methods to those of the XAccessibleComponent interface.
    
    These methods provide information that is used not as often. The division into two interfaces allows classes to support the more frequently used methods of the XAccessibleComponent interface and only support the XAccessibleExtendedComponent interface if that makes sense for the class.
    
    This interface provides extended access to retrieve information concerning the graphical representation of an object. This interface combines methods from the Java interfaces javax.accessibility.AccessibleComponent and javax.accessibility.AccessibleExtendedComponent.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XAccessibleExtendedComponent <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1accessibility_1_1XAccessibleExtendedComponent.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.accessibility.XAccessibleExtendedComponent']

    def getFont(self) -> 'XFont_5f480843':
        """
        Returns the font of this object.
        """
    def getTitledBorderText(self) -> str:
        """
        Returns the titled border text.
        
        This method stems from the Java interface AccessibleExtendedComponent.
        """
    def getToolTipText(self) -> str:
        """
        Returns the tool tip text of this object.
        
        This method stems from the Java interface AccessibleExtendedComponent.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.i18n
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .calendar import Calendar as Calendar_7f2d0962
    from .currency import Currency as Currency_80230993
    from .forbidden_characters import ForbiddenCharacters as ForbiddenCharacters_ce0dd5
    from .format_element import FormatElement as FormatElement_b4c70b7b
    from .implementation import Implementation as Implementation_c1d50c0e
    from .language_country_info import LanguageCountryInfo as LanguageCountryInfo_1f20dec
    from .locale_data_item import LocaleDataItem as LocaleDataItem_beff0ba1
    from ..lang.locale import Locale as Locale_70d308fa

class XLocaleData(XInterface_8f010a43):
    """
    Access locale specific data as it is defined in XML locale data files compiled into the binary data libraries liblocaledata*.so respectively localedata*.dll.
    
    For XML locale data files definitions see the DTD file.

    See Also:
        `API XLocaleData <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1i18n_1_1XLocaleData.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.i18n.XLocaleData']

    def getAllCalendars(self, aLocale: 'Locale_70d308fa') -> 'typing.Tuple[Calendar_7f2d0962, ...]':
        """
        returns all LC_CALENDAR calendars for a locale.
        """
    def getAllCurrencies(self, aLocale: 'Locale_70d308fa') -> 'typing.Tuple[Currency_80230993, ...]':
        """
        returns all LC_CURRENCY currencies for a locale.
        """
    def getAllFormats(self, aLocale: 'Locale_70d308fa') -> 'typing.Tuple[FormatElement_b4c70b7b, ...]':
        """
        returns all LC_FORMAT format elements for a locale.
        """
    def getAllInstalledLocaleNames(self) -> 'typing.Tuple[Locale_70d308fa, ...]':
        """
        returns all available locales.
        """
    def getCollationOptions(self, aLocale: 'Locale_70d308fa') -> 'typing.Tuple[str, ...]':
        """
        returns all LC_COLLATION collation options for a locale.
        """
    def getCollatorImplementations(self, aLocale: 'Locale_70d308fa') -> 'typing.Tuple[Implementation_c1d50c0e, ...]':
        """
        returns all LC_COLLATION collators for a locale.
        """
    def getForbiddenCharacters(self, aLocale: 'Locale_70d308fa') -> 'ForbiddenCharacters_ce0dd5':
        """
        returns all LC_MISC forbidden characters for a locale.
        """
    def getLanguageCountryInfo(self, aLocale: 'Locale_70d308fa') -> 'LanguageCountryInfo_1f20dec':
        """
        returns the LC_INFO locale information.
        """
    def getLocaleItem(self, aLocale: 'Locale_70d308fa') -> 'LocaleDataItem_beff0ba1':
        """
        returns LC_CTYPE separators and markers.
        """
    def getReservedWord(self, aLocale: 'Locale_70d308fa') -> 'typing.Tuple[str, ...]':
        """
        returns all LC_MISC reserved words for a locale.
        """
    def getSearchOptions(self, aLocale: 'Locale_70d308fa') -> 'typing.Tuple[str, ...]':
        """
        returns all LC_SEARCH search options for a locale.
        """
    def getTransliterations(self, aLocale: 'Locale_70d308fa') -> 'typing.Tuple[str, ...]':
        """
        returns all LC_TRANSLITERATION transliterations for a locale.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.report.meta
from typing_extensions import Literal
import typing
from ...container.x_index_access import XIndexAccess as XIndexAccess_f0910d6d
from ...lang.x_component import XComponent as XComponent_98dc0ab5
if typing.TYPE_CHECKING:
    from .x_function_category import XFunctionCategory as XFunctionCategory_59e21055
    from .x_function_description import XFunctionDescription as XFunctionDescription_8d8d119b

class XFunctionManager(XIndexAccess_f0910d6d, XComponent_98dc0ab5):
    """
    identifies a XFunctionManager which allows to retrieve the meta data of all supported functions.

    See Also:
        `API XFunctionManager <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1report_1_1meta_1_1XFunctionManager.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.report.meta.XFunctionManager']

    def getCategory(self, position: int) -> 'XFunctionCategory_59e21055':
        """
        same as getByIndex.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
    def getFunctionByName(self, name: str) -> 'XFunctionDescription_8d8d119b':
        """
        get the function description by name

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.frame
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..beans.string_pair import StringPair as StringPair_a4bc0b14

class XInfobarProvider(XInterface_8f010a43):
    """
    Allows to add Infobars to a frame.
    
    This interface can be obtained via com.sun.star.frame.XController.
    
    **since**
    
        LibreOffice 6.4

    See Also:
        `API XInfobarProvider <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1frame_1_1XInfobarProvider.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.frame.XInfobarProvider']

    def appendInfobar(self, id: str, primaryMessage: str, secondaryMessage: str, infobarType: int, actionButtons: 'typing.Tuple[StringPair_a4bc0b14, ...]', showCloseButton: bool) -> None:
        """
        Creates and displays a new Infobar.
        
        The example below adds a new infobar named MyInfoBar with type INFO and close (x) button.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def hasInfobar(self, id: str) -> bool:
        """
        Check if Infobar exists.
        
        **since**
        
            LibreOffice 7.0
        """
    def removeInfobar(self, id: str) -> None:
        """
        Removes an existing Infobar.
        
        Remove MyInfoBar infobar

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """
    def updateInfobar(self, id: str, primaryMessage: str, secondaryMessage: str, infobarType: int) -> None:
        """
        Updates an existing Infobar.
        
        Use if you want to update only small parts of the Infobar.
        
        Update the infobar and change the type to WARNING

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.formula
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing


class SymbolDescriptor(object):
    """
    Struct Class

    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API SymbolDescriptor <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1formula_1_1SymbolDescriptor.html>`_
    """
    typeName: Literal['com.sun.star.formula.SymbolDescriptor']

    def __init__(self, sName: typing.Optional[str] = ..., sExportName: typing.Optional[str] = ..., sSymbolSet: typing.Optional[str] = ..., nCharacter: typing.Optional[int] = ..., sFontName: typing.Optional[str] = ..., nCharSet: typing.Optional[int] = ..., nFamily: typing.Optional[int] = ..., nPitch: typing.Optional[int] = ..., nWeight: typing.Optional[int] = ..., nItalic: typing.Optional[int] = ...) -> None:
        """
        Constructor

        Arguments:
            sName (str, optional): sName value.
            sExportName (str, optional): sExportName value.
            sSymbolSet (str, optional): sSymbolSet value.
            nCharacter (int, optional): nCharacter value.
            sFontName (str, optional): sFontName value.
            nCharSet (int, optional): nCharSet value.
            nFamily (int, optional): nFamily value.
            nPitch (int, optional): nPitch value.
            nWeight (int, optional): nWeight value.
            nItalic (int, optional): nItalic value.
        """


    @property
    def sName(self) -> str:
        """
        The name of the symbol.
        """


    @property
    def sExportName(self) -> str:
        """
        The export name of the symbol.
        """


    @property
    def sSymbolSet(self) -> str:
        """
        Specifies the name of the symbol set to which this symbol belongs.
        """


    @property
    def nCharacter(self) -> int:
        """
        Specifies the Unicode character of the symbol.
        """


    @property
    def sFontName(self) -> str:
        """
        Specifies the exact name of the font (\"Arial\", \"Courier\", etc.).
        """


    @property
    def nCharSet(self) -> int:
        """
        Specifies the character set which is supported by the font.
        """


    @property
    def nFamily(self) -> int:
        """
        Specifies the general style of the font.
        """


    @property
    def nPitch(self) -> int:
        """
        Specifies the pitch of the font.
        """


    @property
    def nWeight(self) -> int:
        """
        Specifies the thickness of the line.
        
        The allowed integer values correspond as follows: 0 : com.sun.star.awt.FontWeight.DONTKNOW 1 : com.sun.star.awt.FontWeight.THIN 2 : com.sun.star.awt.FontWeight.ULTRALIGHT 3 : com.sun.star.awt.FontWeight.LIGHT 4 : com.sun.star.awt.FontWeight.SEMILIGHT 5 : com.sun.star.awt.FontWeight.NORMAL 7 : com.sun.star.awt.FontWeight.SEMIBOLD 8 : com.sun.star.awt.FontWeight.BOLD 9 : com.sun.star.awt.FontWeight.ULTRABOLD 10 : com.sun.star.awt.FontWeight.BLACK
        """


    @property
    def nItalic(self) -> int:
        """
        Specifies if the font is italic.
        
        The values com.sun.star.awt.FontSlant.REVERSE_OBLIQUE and com.sun.star.awt.FontSlant.REVERSE_ITALIC may not be used.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.util
from typing_extensions import Literal
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XStringSubstitution(XInterface_8f010a43):
    """
    A common interface for substituting string variables with other strings.
    
    The substitution algorithm and the syntax for a string variable are not part of this interface definition. Please look at the documentation of the implementation that must specify these parameters.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XStringSubstitution <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1util_1_1XStringSubstitution.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.util.XStringSubstitution']

    def getSubstituteVariableValue(self, variable: str) -> str:
        """
        Returns the current value of a variable.
        
        The method iterates through its internal variable list and tries to find the given variable. If the variable is unknown a com.sun.star.container.NoSuchElementException is thrown.

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """
    def reSubstituteVariables(self, aText: str) -> str:
        """
        Tries to replace parts of aText with variables that represents these sub strings.
        
        The method iterates through its internal variable list and tries to match parts of the given string Tries to replace parts of aText with variables that represents these sub strings.If more than one variable matches the one with the longest matching sub string will be chosen.
        """
    def substituteVariables(self, aText: str, bSubstRequired: bool) -> str:
        """
        Exchanges variables inside a given text with a substitution text defined for the variables.
        
        The method iterates through its internal variables list to match the variables in the given string. A match replaces the variable with the string defined for this variable. If no variable can be found in the string it will be returned unchanged. The behavior if a variable is found in the string but it is unknown for the implementation depends on the parameter bSubstRequired.

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.system
from typing_extensions import Literal


class SimpleMailClientFlags(object):
    """
    Const

    These constants are used to specify how the SimpleMailClient Service should behave.

    See Also:
        `API SimpleMailClientFlags <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1system_1_1SimpleMailClientFlags.html>`_
    """
    DEFAULTS: Literal[0]
    """
    Uses the default settings when sending a mail, e.g.
    
    launches the current configured system mail client.
    """
    NO_USER_INTERFACE: Literal[1]
    """
    Does not show the current configured system mail client, but sends the mail without any further user interaction.
    
    If this flag is specified, a recipient address must have been specified for the given XSimpleMailMessage object given to the method com.sun.star.system.XSimpleMailClient.sendSimpleMailMessage().
    """
    NO_LOGON_DIALOG: Literal[2]
    """
    No logon dialog should be displayed to prompt the user for logon information if necessary.
    
    When this flag is specified and the user needs to logon in order to send a simple mail message via the method com.sun.star.system.XSimpleMailClient.sendSimpleMailMessage(), an Exception will be thrown.
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.linguistic2
from .x_conversion_dictionary_list import XConversionDictionaryList as XConversionDictionaryList_ec3713a5

class ConversionDictionaryList(XConversionDictionaryList_ec3713a5):
    """
    Service Class

    represents a list of available conversion dictionaries.
    
    There will be only one list that may hold different types of conversion dictionaries. That is e.g. it may hold dictionaries for Korean Hangul/Hanja conversion along with ones for Chinese traditional/simplified conversion or conversion between different Indic script types.
    
    The list will be used by the text conversion service to check for user supplied text conversions.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API ConversionDictionaryList <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1linguistic2_1_1ConversionDictionaryList.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.animations
from typing_extensions import Literal
from .x_time_container import XTimeContainer as XTimeContainer_1cca0ec5

class XIterateContainer(XTimeContainer_1cca0ec5):
    """
    An iterate container iterates over subitems of a given target object and animates them by subsequently executes the contained effects on them.
    
    This could be used to animate a target text word by word or letter by letter.

    See Also:
        `API XIterateContainer <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1animations_1_1XIterateContainer.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.animations.XIterateContainer']

    @property
    def IterateInterval(self) -> float:
        """
        the time interval in second before the next iterated content is animated.
        """

    @property
    def IterateType(self) -> int:
        """
        the type of iteration, this depends on the target.
        
        See documentation of used animation engine for supported iteration types.
        """

    @property
    def SubItem(self) -> int:
        """
        This attribute specifies an optional subitem from the target element that should be animated.
        
        A value of zero should always be the default and animate the complete target.
        See documentation of used animation engine for supported subitems.
        """

    @property
    def Target(self) -> object:
        """
        a target that contains iterable contents, f.e.
        
        a paragraph.
        See documentation of used animation engine for supported targets.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sheet
from typing_extensions import Literal


class DataPilotOutputRangeType(object):
    """
    Const

    specifies region type of DataPilot table range
    
    This constant set is used to indicate the type of output range desired when XDataPilotTable2.getOutputRangeByType() is called, which returns a different cell range depending upon the value passed to it as the argument.
    
    **since**
    
        OOo 3.0

    See Also:
        `API DataPilotOutputRangeType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1sheet_1_1DataPilotOutputRangeType.html>`_
    """
    WHOLE: Literal[0]
    """
    whole DataPilot output range including the header area above the table where the filter and page field buttons are located.
    """
    TABLE: Literal[1]
    """
    whole table but without the header area where the filter and page field buttons are located.
    """
    RESULT: Literal[2]
    """
    result area where the result values are displayed.
    
    This also includes the column and row subtotal areas when they are displayed.
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.awt.grid
from typing_extensions import Literal
from abc import ABC

class XGridControl(ABC):
    """
    An interface to a control that displays a tabular data.
    
    **since**
    
        OOo 3.3

    See Also:
        `API XGridControl <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1grid_1_1XGridControl.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.awt.grid.XGridControl']

    def getColumnAtPoint(self, X: int, Y: int) -> int:
        """
        retrieves the column which a given point belongs to
        """
    def getCurrentColumn(self) -> int:
        """
        returns the column index of the currently active cell
        
        If the grid control's does not contain any cells (which happens if the grid column model does not contain any columns, or if grid data model does not contain any rows), then -1 is returned.
        """
    def getCurrentRow(self) -> int:
        """
        returns the row index of the currently active cell
        
        If the grid control's does not contain any cells (which happens if the grid column model does not contain any columns, or if grid data model does not contain any rows), then -1 is returned.
        """
    def getRowAtPoint(self, X: int, Y: int) -> int:
        """
        retrieves the row which a given point belongs to
        """
    def goToCell(self, ColumnIndex: int, RowIndex: int) -> None:
        """
        moves the cursor to the given cell

        Raises:
            : ````
            com.sun.star.util.VetoException: ``VetoException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Singleton Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ui
# Libre Office Version: 7.3
from ..container.x_name_access import XNameAccess as XNameAccess_e2ab0cf6


class theWindowStateConfiguration(XNameAccess_e2ab0cf6):
    """
    Singleton Class

    a singleton which provides window based information about user interface elements.
    
    OpenOffice.org has an amount of user interface elements that can be positioned, resized, closed and their style can be changed. This singleton provides access to the window based information of available user interface elements which are part of OpenOffice.org modules, like Writer or Calc.
    
    Provides access to window based information about user interface elements of all installed application modules.
    
    To access the window based information of a module, a unique module specifier must be provided to com.sun.star.container.XNameAccess.getByName() function. The module specifier can be retrieved from the com.sun.star.frame.ModuleManager service. The interface provides references to a com.sun:star.ui.ModuleWindowStateConfiguration.
    
    Prior to LibreOffice 4.3, this singleton was only available as a (single-instance) WindowStateConfiguration service.
    
    **since**
    
        LibreOffice 4.3

    See Also:
        `API theWindowStateConfiguration <https://api.libreoffice.org/docs/idl/ref/singletoncom_1_1sun_1_1star_1_1ui_1_1theWindowStateConfiguration.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.rendering
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..geometry.integer_size2_d import IntegerSize2D as IntegerSize2D_f2690d53
    from ..geometry.real_size2_d import RealSize2D as RealSize2D_ca1a0c09

class XBitmap(XInterface_8f010a43):
    """
    This is a generic interface to a bitmap.
    
    This interface contains the generic functionality to be used on every XCanvas bitmap object. More format-specific methods can be found at the XIntegerBitmap, XIeeeDoubleBitmap, XIeeeFloatBitmap and XHalfFloatBitmap interfaces.
    
    **since**
    
        OOo 2.0

    See Also:
        `API XBitmap <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1rendering_1_1XBitmap.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.rendering.XBitmap']

    def getScaledBitmap(self, newSize: 'RealSize2D_ca1a0c09', beFast: bool) -> 'XBitmap':
        """
        Query a scaled copy of the original bitmap.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            VolatileContentDestroyedException: ``VolatileContentDestroyedException``
        """
    def getSize(self) -> 'IntegerSize2D_f2690d53':
        """
        Query the size of the bitmap.
        
        This method queries the bitmap size in pixel.
        """
    def hasAlpha(self) -> bool:
        """
        Query transparency status of the bitmap.
        
        The method checks, whether the bitmap contains any alpha information. The same information is also available at the XColorSpace associated with this bitmap, though much easier to access here (the color space then has a component flagged ColorComponentTag.ALPHA).
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.rendering
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing
from .color_component import ColorComponent as ColorComponent_e4c0e78


class ARGBColor(object):
    """
    Struct Class

    ARGB color quad.

    See Also:
        `API ARGBColor <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1rendering_1_1ARGBColor.html>`_
    """
    typeName: Literal['com.sun.star.rendering.ARGBColor']

    def __init__(self, Alpha: typing.Optional[ColorComponent_e4c0e78] = ..., Red: typing.Optional[ColorComponent_e4c0e78] = ..., Green: typing.Optional[ColorComponent_e4c0e78] = ..., Blue: typing.Optional[ColorComponent_e4c0e78] = ...) -> None:
        """
        Constructor

        Arguments:
            Alpha (ColorComponent, optional): Alpha value.
            Red (ColorComponent, optional): Red value.
            Green (ColorComponent, optional): Green value.
            Blue (ColorComponent, optional): Blue value.
        """


    @property
    def Alpha(self) -> ColorComponent_e4c0e78:
        """
        Alpha component.
        
        Valid range is [0,1.0], with 0.0 denoting fully transparent, and 1.0 fully opaque.
        """


    @property
    def Red(self) -> ColorComponent_e4c0e78:
        """
        Red component. Valid range is [0,1.0].
        """


    @property
    def Green(self) -> ColorComponent_e4c0e78:
        """
        Green component. Valid range is [0,1.0].
        """


    @property
    def Blue(self) -> ColorComponent_e4c0e78:
        """
        Blue component. Valid range is [0,1.0].
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.util
from typing_extensions import Literal
"""
Const

These constants are used to specify a measure.

A component using these constants may not support all units.

See Also:
    `API MeasureUnit <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1util_1_1MeasureUnit.html>`_
"""
MM_100TH: Literal[0]
"""
all measures for this component are in 100th millimeter
"""
MM_10TH: Literal[1]
"""
all measures for this component are in 10th millimeter
"""
MM: Literal[2]
"""
all measures for this component are in millimeter
"""
CM: Literal[3]
"""
all measures for this component are in centimeters
"""
INCH_1000TH: Literal[4]
"""
all measures for this component are in 1000th inch
"""
INCH_100TH: Literal[5]
"""
all measures for this component are in 100th inch
"""
INCH_10TH: Literal[6]
"""
all measures for this component are in 10th inch
"""
INCH: Literal[7]
"""
all measures for this component are in inch
"""
POINT: Literal[8]
"""
all measures for this component are in points
"""
TWIP: Literal[9]
"""
all measures for this component are in twips
"""
M: Literal[10]
"""
all measures for this component are in meters
"""
KM: Literal[11]
"""
all measures for this component are in kilometers
"""
PICA: Literal[12]
"""
all measures for this component are in pica
"""
FOOT: Literal[13]
"""
all measures for this component are in foot
"""
MILE: Literal[14]
"""
all measures for this component are in miles
"""
PERCENT: Literal[15]
"""
all measures for this component are in percentage
"""
PIXEL: Literal[16]
"""
all measures for this component are in pixel
"""
APPFONT: Literal[17]
"""
all measures for this component are in APPFONT
"""
SYSFONT: Literal[18]
"""
all measures for this component are in SYSFONT
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.form
# Libre Office Version: 7.3
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    import uno
"""
Enum



See Also:
    `API FormSubmitEncoding <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1form.html#a4a4c5c07c0618f59711919741a523ab8>`_
"""

MULTIPART: 'uno.Enum'
"""
Specifies to use \"multipart/form-data\" as submit encoding.

Usually used when the form contains a file upload element.
"""
TEXT: 'uno.Enum'
"""
specifies to use \"text/plain\"

Usually used if the FormSubmitMethod attribute has the value POST and the content should be reviewed as full text.
"""
URL: 'uno.Enum'
"""
When the button is clicked, a URL set for the button is opened.

Specifies to use \"application/x-www-form-urlencoded\" as submit encoding.

Usually used if the FormSubmitMethod attribute has the value POST.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.ui
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .context_change_event_object import ContextChangeEventObject as ContextChangeEventObject_37b70f6a
    from .x_context_change_event_listener import XContextChangeEventListener as XContextChangeEventListener_678510b1

class XContextChangeEventMultiplexer(XInterface_8f010a43):
    """
    Provide a central access point for a group of events.
    
    Listeners can be added with a simple restriction on the event source. They are only called for events that originate at the specified source.
    
    Event providers can broadcast an event to all interested listeners.
    
    The XEventMultiplexer interface is typically implemented as a singleton

    See Also:
        `API XContextChangeEventMultiplexer <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ui_1_1XContextChangeEventMultiplexer.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.ui.XContextChangeEventMultiplexer']

    def addContextChangeEventListener(self, xListener: 'XContextChangeEventListener_678510b1', xEventFocus: 'XInterface_8f010a43') -> None:
        """
        Add an event listener that is called only when events are broadcast for the specified event focus.
        
        One listener may be added more than once for different event foci. Adding a listener a second time for the same event focus results in an InvalidArgumentException.
        
        The event focus may or may not be the source of the event.
        
        A typical example for an event focus is the XController of a view. Using an XController restricts events passed to a listener to events that belong to one view.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def broadcastContextChangeEvent(self, aEvent: 'ContextChangeEventObject_37b70f6a', xEventFocus: 'XInterface_8f010a43') -> None:
        """
        Call all event listeners that were added for the specified event focus.
        """
    def removeAllContextChangeEventListeners(self, xListener: 'XContextChangeEventListener_678510b1') -> None:
        """
        Remove an event listener for all event foci.
        
        It is not an error when the listener is not registered for any event focus.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def removeContextChangeEventListener(self, xListener: 'XContextChangeEventListener_678510b1', xEventFocus: 'XInterface_8f010a43') -> None:
        """
        Remove an event listener for the specified event focus.
        
        When the same listener was added for other event foci then these associations remain unmodified.
        
        When the listener is not registered for the given event focus then an InvalidArgumentException is thrown.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Exception Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.task
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing
from .document_password_request import DocumentPasswordRequest as DocumentPasswordRequest_4bb71036
from ..uno.x_interface import XInterface as XInterface_8f010a43
from .interaction_classification import InteractionClassification as InteractionClassification_6c4d10e7
from .password_request_mode import PasswordRequestMode as PasswordRequestMode_ec10e7c

class DocumentPasswordRequest2(DocumentPasswordRequest_4bb71036):
    """
    Exception Class

    this request specifies if a password for opening or modifying a document is requested.
    
    It is supported by InteractionHandler service, and can be used to interact for a document password. Continuations for using with the mentioned service are Abort and Approve.
    
    **since**
    
        OOo 3.3

    See Also:
        `API DocumentPasswordRequest2 <https://api.libreoffice.org/docs/idl/ref/exceptioncom_1_1sun_1_1star_1_1task_1_1DocumentPasswordRequest2.html>`_
    """

    typeName: Literal['com.sun.star.task.DocumentPasswordRequest2']

    def __init__(self, Message: typing.Optional[str] = ..., Context: typing.Optional[XInterface_8f010a43] = ..., Classification: typing.Optional[InteractionClassification_6c4d10e7] = ..., Mode: typing.Optional[PasswordRequestMode_ec10e7c] = ..., Name: typing.Optional[str] = ..., IsRequestPasswordToModify: typing.Optional[bool] = ...) -> None:
        """
        Constructor

        Arguments:
            Message (str, optional): Message value.
            Context (XInterface, optional): Context value.
            Classification (InteractionClassification, optional): Classification value.
            Mode (PasswordRequestMode, optional): Mode value.
            Name (str, optional): Name value.
            IsRequestPasswordToModify (bool, optional): IsRequestPasswordToModify value.
        """
    @property
    def IsRequestPasswordToModify(self) -> bool:
        """
        specifies if the requested password is for opening a document or for modifying it.
        """


__all__ = ['DocumentPasswordRequest2']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sheet
from typing_extensions import Literal


class ConditionOperator2(object):
    """
    Const

    is used to specify the type of XSheetCondition2.

    See Also:
        `API ConditionOperator2 <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1sheet_1_1ConditionOperator2.html>`_
    """
    NONE: Literal[0]
    """
    no condition is specified.
    """
    EQUAL: Literal[1]
    """
    value has to be equal to the specified value.
    """
    NOT_EQUAL: Literal[2]
    """
    the value must not be equal to the specified value.
    """
    GREATER: Literal[3]
    """
    the value has to be greater than the specified value.
    """
    GREATER_EQUAL: Literal[4]
    """
    the value has to be greater than or equal to the specified value.
    """
    LESS: Literal[5]
    """
    the value has to be less than the specified value.
    """
    LESS_EQUAL: Literal[6]
    """
    the value has to be less than or equal to the specified value.
    """
    BETWEEN: Literal[7]
    """
    the value has to be between the two specified values.
    """
    NOT_BETWEEN: Literal[8]
    """
    the value has to be outside of the two specified values.
    """
    FORMULA: Literal[9]
    """
    the specified formula has to give a non-zero result.
    """
    DUPLICATE: Literal[10]
    """
    Conditionally format duplicate values.
    """
    NOT_DUPLICATE: Literal[11]
    """
    Conditionally format non-duplicate values.
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.ui.dialogs
from typing_extensions import Literal
import typing
from .x_executable_dialog import XExecutableDialog as XExecutableDialog_450f0fa1

class XFilePicker(XExecutableDialog_450f0fa1):
    """
    Specifies an interface for a FilePicker.

    See Also:
        `API XFilePicker <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XFilePicker.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.ui.dialogs.XFilePicker']

    def getDisplayDirectory(self) -> str:
        """
        Returns the directory that the file dialog is currently showing or was last showing before closing the dialog with Ok.
        
        If the user did cancel the dialog, the returned value is undefined.
        """
    def getFiles(self) -> 'typing.Tuple[str, ...]':
        """
        Returns a sequence of the selected files including path information in URL format, conforming to Rfc1738.
        
        If the user closed the dialog with cancel an empty sequence will be returned.
        
        If the dialog is in execution mode and a single file is selected the complete URL of this file will be returned.
        
        If the dialog is in execution mode and the selected file name is false or any other error occurs an empty sequence will be returned.
        
        The complete path of the file or directory currently selected in URL format. This always returns only the first entry of the sequence.
        
        Notes for the implementation of a FileSave dialog:If there exists a checkbox \"Automatic File Extension\" which is checked and a valid filter is currently selected the dialog may automatically add an extension to the selected file name.
        """
    def setDefaultName(self, aName: str) -> None:
        """
        Sets the default string that appears in the file name box of a FilePicker.
        
        Specifies the default file name, displayed when the FilePicker is shown. The implementation may accept any string, and does not have to check for a valid file name or if the file really exists.
        """
    def setDisplayDirectory(self, aDirectory: str) -> None:
        """
        Sets the directory that the file dialog initially displays.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def setMultiSelectionMode(self, bMode: bool) -> None:
        """
        Enable/disable multi-selection mode.
        
        If the multi-selection mode is enabled, multiple files may be selected by the user else only one file selection at a time is possible
        
        A value of TRUE enables the multi-selection mode.
        
        A value of FALSE disables the multi-selection mode, this is the default.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sheet
from typing_extensions import Literal
"""
Const

is used to specify the type of XSheetCondition2.

See Also:
    `API ConditionOperator2 <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1sheet_1_1ConditionOperator2.html>`_
"""
NONE: Literal[0]
"""
no condition is specified.
"""
EQUAL: Literal[1]
"""
value has to be equal to the specified value.
"""
NOT_EQUAL: Literal[2]
"""
the value must not be equal to the specified value.
"""
GREATER: Literal[3]
"""
the value has to be greater than the specified value.
"""
GREATER_EQUAL: Literal[4]
"""
the value has to be greater than or equal to the specified value.
"""
LESS: Literal[5]
"""
the value has to be less than the specified value.
"""
LESS_EQUAL: Literal[6]
"""
the value has to be less than or equal to the specified value.
"""
BETWEEN: Literal[7]
"""
the value has to be between the two specified values.
"""
NOT_BETWEEN: Literal[8]
"""
the value has to be outside of the two specified values.
"""
FORMULA: Literal[9]
"""
the specified formula has to give a non-zero result.
"""
DUPLICATE: Literal[10]
"""
Conditionally format duplicate values.
"""
NOT_DUPLICATE: Literal[11]
"""
Conditionally format non-duplicate values.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.text
from typing_extensions import Literal


class HoriOrientation(object):
    """
    Const

    These enumeration values specify the horizontal orientation.

    See Also:
        `API HoriOrientation <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1text_1_1HoriOrientation.html>`_
    """
    NONE: Literal[0]
    """
    no hard alignment is applied.
    """
    RIGHT: Literal[1]
    """
    The object is aligned at the right side.
    """
    CENTER: Literal[2]
    """
    The object is aligned at the middle.
    """
    LEFT: Literal[3]
    """
    The object is aligned at the left side.
    """
    INSIDE: Literal[4]
    """
    TODO.
    """
    OUTSIDE: Literal[5]
    """
    TODO.
    """
    FULL: Literal[6]
    """
    The object uses the full space (for text tables only).
    """
    LEFT_AND_WIDTH: Literal[7]
    """
    The left offset and the width of the object are defined.
    
    For text tables this means that the tables position is defined by the left margin and the width.
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.i18n
from typing_extensions import Literal
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XScriptTypeDetector(XInterface_8f010a43):
    """
    contains the help routines for layouting complex text
    
    Assumption - StartPos is inclusive and EndPos is exclusive.
    
    The nScriptDirection parameters are of type ScriptDirection
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XScriptTypeDetector <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1i18n_1_1XScriptTypeDetector.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.i18n.XScriptTypeDetector']

    def beginOfCTLScriptType(self, aText: str, nPos: int) -> int:
        """
        """
    def beginOfScriptDirection(self, aText: str, nPos: int, nScriptDirection: int) -> int:
        """
        """
    def endOfCTLScriptType(self, aText: str, nPos: int) -> int:
        """
        """
    def endOfScriptDirection(self, aText: str, nPos: int, nScriptDirection: int) -> int:
        """
        """
    def getCTLScriptType(self, aText: str, nPos: int) -> int:
        """
        """
    def getScriptDirection(self, aText: str, nPos: int, nDefaultScriptDirection: int) -> int:
        """
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.ui
from typing_extensions import Literal
import typing
from abc import ABC
if typing.TYPE_CHECKING:
    from .x_panels import XPanels as XPanels_676608a1

class XDeck(ABC):
    """
    provides access to Deck
    
    **since**
    
        LibreOffice 5.1

    See Also:
        `API XDeck <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ui_1_1XDeck.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.ui.XDeck']

    def activate(self, bActivate: bool) -> None:
        """
        Activate the deck and display its content.
        """
    def getId(self) -> str:
        """
        The deck identifier.
        """
    def getOrderIndex(self) -> int:
        """
        Get the ordering index of the deck button in sidebar.
        """
    def getPanels(self) -> 'XPanels_676608a1':
        """
        Panels collection attached to the deck.
        """
    def getTitle(self) -> str:
        """
        Get the deck title string.
        """
    def isActive(self) -> bool:
        """
        Is the deck the active one.
        """
    def moveDown(self) -> None:
        """
        Move deck one step down in the sidebar.
        """
    def moveFirst(self) -> None:
        """
        Move deck button at first position in sidebar.
        """
    def moveLast(self) -> None:
        """
        Move deck button at last position in sidebar.
        """
    def moveUp(self) -> None:
        """
        Move deck one step up in the sidebar.
        """
    def setOrderIndex(self, newOrderIndex: int) -> None:
        """
        Set the ordering index of the deck button in sidebar.
        """
    def setTitle(self, newTitle: str) -> None:
        """
        Set the deck title string.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.ucb
from .x_content_provider import XContentProvider as XContentProvider_d4150cc0

class TransientDocumentsContentProvider(XContentProvider_d4150cc0):
    """
    Service Class

    The Transient Documents Content Provider (TDCP) implements a ContentProvider for the UniversalContentBroker (UCB).
    
    It provides access to the hierarchical structure of the documents that are active in a running OpenOffice.org process. As long as a document was not closed, the TDCP can access it. All documents that have been loaded - regardless of their persistent document format (sxw, doc, sxc, xls, ...) or that have been created but not yet saved to any storage medium, are supported. The TDCP is not able to load any documents itself. This is exclusively done by the OpenOffice.org document handling framework. The document contents provided by the TDCP represent live data, which may differ from any persistent representation of the document, for instance, because the user modified the document after loading, but did not yet save it.
    
    **since**
    
        OOo 2.0

    See Also:
        `API TransientDocumentsContentProvider <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1ucb_1_1TransientDocumentsContentProvider.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sheet
from typing_extensions import Literal
import typing
from ..container.x_name_access import XNameAccess as XNameAccess_e2ab0cf6
if typing.TYPE_CHECKING:
    from .border import Border as Border_7b2c097f
    from ..table.cell_address import CellAddress as CellAddress_ae5f0b56
    from ..table.cell_range_address import CellRangeAddress as CellRangeAddress_ec450d43

class XNamedRanges(XNameAccess_e2ab0cf6):
    """
    provides access to the members in a collection of named ranges and to insert and remove them.

    See Also:
        `API XNamedRanges <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sheet_1_1XNamedRanges.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.sheet.XNamedRanges']

    def addNewByName(self, aName: str, aContent: str, aPosition: 'CellAddress_ae5f0b56', nType: int) -> None:
        """
        adds a new named range to the collection.
        
        A cell range address is one possible content of a named range.
        
        This parameter will be zero for any common named range.
        """
    def addNewFromTitles(self, aSource: 'CellRangeAddress_ec450d43', aBorder: 'Border_7b2c097f') -> None:
        """
        creates named cell ranges from titles in a cell range.
        
        The names for the named ranges are taken from title cells in the top or bottom row, or from the cells of the left or right column of the range (depending on the parameter aBorder. The named ranges refer to single columns or rows in the inner part of the original range, excluding the labels.
        
        Example: The source range is A1:B3. The named ranges shall be created using row titles. This requires Border.TOP for the second parameter. The method creates two named ranges. The name of the first is equal to the content of cell A1 and contains the range $Sheet.$A$2:$A$3 (excluding the title cell). The latter named range is named using cell B1 and contains the cell range address $Sheet.$B$2:$B$3.
        """
    def outputList(self, aOutputPosition: 'CellAddress_ae5f0b56') -> None:
        """
        writes a list of all named ranges into the document.
        
        The first column of the list contains the names. The second column contains the contents of the named ranges.
        """
    def removeByName(self, aName: str) -> None:
        """
        removes a named range from the collection.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.uno
from typing_extensions import Literal
from .x_interface import XInterface as XInterface_8f010a43

class XAggregation(XInterface_8f010a43):
    """
    Objects which implement this interface can become aggregates of a delegator.
    
    That means if an object \"A\" aggregates \"B\", \"A\" can provide all or some of the interfaces of \"B\". Whenever the method XInterface.queryInterface() is called on either of the objects, the call will be forwarded to object \"A\". Object \"A\" now can determine whether to use the interfaces of \"A\" or \"B\" or neither. Actually, any number of aggregates can be used, even nested ones (aggregated objects which are delegators by themselves).
    
    The following rules are to be observed:
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API XAggregation <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1uno_1_1XAggregation.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.uno.XAggregation']

    def queryAggregation(self, aType: object) -> object:
        """
        is similar to XInterface.queryInterface(), but it is to be processed directly without being forwarded to the delegator.
        
        This method is only called from within an implementation of XInterface.queryInterface() or XAggregation.queryAggregation(). This method is to be called by the delegator if it does not implement the interface itself. An object which got aggregated cannot depend on getting its own interface when it calls the method XInterface.queryInterface().
        """
    def setDelegator(self, pDelegator: 'XInterface_8f010a43') -> None:
        """
        sets the object to which all calls to the method XInterface.queryInterface() have to be forwarded.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sheet
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..table.cell_address import CellAddress as CellAddress_ae5f0b56

class XSheetAuditing(XInterface_8f010a43):
    """
    provides methods to access auditing (detective) features in a spreadsheet.

    See Also:
        `API XSheetAuditing <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetAuditing.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.sheet.XSheetAuditing']

    def clearArrows(self) -> None:
        """
        removes all auditing arrows from the spreadsheet.
        """
    def hideDependents(self, aPosition: 'CellAddress_ae5f0b56') -> bool:
        """
        removes arrows for one level of dependents of a formula cell.
        
        If the method is executed again for the same cell, the previous level of dependent cells is removed.
        """
    def hidePrecedents(self, aPosition: 'CellAddress_ae5f0b56') -> bool:
        """
        removes arrows for one level of precedents of a formula cell.
        
        If the method is executed again for the same cell, the previous level of dependent cells is removed.
        """
    def showDependents(self, aPosition: 'CellAddress_ae5f0b56') -> bool:
        """
        draws arrows between a formula cell and its dependents.
        
        If the method is executed again for the same cell, the next level of dependent cells is marked.
        """
    def showErrors(self, aPosition: 'CellAddress_ae5f0b56') -> bool:
        """
        draws arrows between a formula cell containing an error and the cells causing the error.
        """
    def showInvalid(self) -> bool:
        """
        marks all cells containing invalid values.
        """
    def showPrecedents(self, aPosition: 'CellAddress_ae5f0b56') -> bool:
        """
        draws arrows between a formula cell and its precedents.
        
        If the method is executed again for the same cell, the next level of dependent cells is marked.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.document
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing


class CmisVersion(object):
    """
    Struct Class

    specifies a CMIS document version.

    See Also:
        `API CmisVersion <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1document_1_1CmisVersion.html>`_
    """
    typeName: Literal['com.sun.star.document.CmisVersion']

    def __init__(self, Id: typing.Optional[str] = ..., TimeStamp: typing.Optional[object] = ..., Author: typing.Optional[str] = ..., Comment: typing.Optional[str] = ...) -> None:
        """
        Constructor

        Arguments:
            Id (str, optional): Id value.
            TimeStamp (object, optional): TimeStamp value.
            Author (str, optional): Author value.
            Comment (str, optional): Comment value.
        """


    @property
    def Id(self) -> str:
        """
        unique ID of the Cmis version
        """


    @property
    def TimeStamp(self) -> object:
        """
        specifies the time when the revision was created.
        """


    @property
    def Author(self) -> str:
        """
        contains the author that created the version.
        """


    @property
    def Comment(self) -> str:
        """
        contains the comment the author has left.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.chart2.data
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing


class HighlightedRange(object):
    """
    Struct Class


    See Also:
        `API HighlightedRange <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1chart2_1_1data_1_1HighlightedRange.html>`_
    """
    typeName: Literal['com.sun.star.chart2.data.HighlightedRange']

    def __init__(self, RangeRepresentation: typing.Optional[str] = ..., Index: typing.Optional[int] = ..., PreferredColor: typing.Optional[int] = ..., AllowMerginigWithOtherRanges: typing.Optional[bool] = ...) -> None:
        """
        Constructor

        Arguments:
            RangeRepresentation (str, optional): RangeRepresentation value.
            Index (int, optional): Index value.
            PreferredColor (int, optional): PreferredColor value.
            AllowMerginigWithOtherRanges (bool, optional): AllowMerginigWithOtherRanges value.
        """


    @property
    def RangeRepresentation(self) -> str:
        """
        The range representation string of the highlighted range.
        """


    @property
    def Index(self) -> int:
        """
        Only take the cell at position Index out of the given Range.
        
        If this value is -1 take the whole sequence.
        """


    @property
    def PreferredColor(self) -> int:
        """
        Use this color for marking the range.
        
        This color may be ignored and replaced by a better fitting color, if it would be otherwise not well visible.
        """


    @property
    def AllowMerginigWithOtherRanges(self) -> bool:
        """
        If the highlighted range is visually highlighted and this member is TRUE, the range given in RangeRepresentation may be included in a merged range rectangle spanning a bigger range.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.ucb
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .command import Command as Command_709c0901
    from .x_command_environment import XCommandEnvironment as XCommandEnvironment_fb330dee

class XCommandProcessor(XInterface_8f010a43):
    """
    defines a processor for synchronous commands, which are executed in a specific execution environment.

    See Also:
        `API XCommandProcessor <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ucb_1_1XCommandProcessor.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.ucb.XCommandProcessor']

    def abort(self, CommandId: int) -> None:
        """
        ends the command associated with the given id.
        
        Not every command can be aborted. It's up to the implementation to decide whether this method will actually end the processing of the command or simply do nothing.
        """
    def createCommandIdentifier(self) -> int:
        """
        creates a unique identifier for a command.
        
        This identifier can be used to abort the execution of the command associated with that identifier. Note that it is generally not necessary to obtain a new id for each command, because commands are executed synchronously. So the id for a command is valid again after a command previously associated with this id has finished. In fact you only should get one identifier per thread and assign it to every command executed by that thread.
        
        Also, after a call to XCommandProcessor.abort(), an identifier should not be used any longer (and instead be released by a call to XCommandProcessor2.releaseCommandIdentifier()), because it may well abort all further calls to XCommandProcessor.execute().
        
        To avoid ever-increasing resource consumption, the identifier should be released via XCommandProcessor2.releaseCommandIdentifier() when it is no longer used.
        """
    def execute(self, aCommand: 'Command_709c0901', CommandId: int, Environment: 'XCommandEnvironment_fb330dee') -> object:
        """
        executes a command.
        
        Common command definitions can be found in the specification of the service Content.

        Raises:
            com.sun.star.uno.Exception: ``Exception``
            CommandAbortedException: ``CommandAbortedException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sheet
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .fill_date_mode import FillDateMode as FillDateMode_bb000bab
    from .fill_direction import FillDirection as FillDirection_c7f00c49
    from .fill_mode import FillMode as FillMode_8ee80a2d

class XCellSeries(XInterface_8f010a43):
    """
    provides methods to fill out a cell range automatically with values based on a start value, step count and fill mode.

    See Also:
        `API XCellSeries <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sheet_1_1XCellSeries.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.sheet.XCellSeries']

    def fillAuto(self, nFillDirection: 'FillDirection_c7f00c49', nSourceCount: int) -> None:
        """
        fills all cells in the range in a way that is specified by the first cell(s) in the range.
        """
    def fillSeries(self, nFillDirection: 'FillDirection_c7f00c49', nFillMode: 'FillMode_8ee80a2d', nFillDateMode: 'FillDateMode_bb000bab', fStep: float, fEndValue: float) -> None:
        """
        fills all cells in the range based on the specified settings.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.bridge
from .x_bridge_factory2 import XBridgeFactory2 as XBridgeFactory2_ecc10d24

class BridgeFactory(XBridgeFactory2_ecc10d24):
    """
    Service Class

    allows to create new or access existing interprocess bridges.
    
    It enumerates at the servicemanager all services supporting the meta service com.sun.star.bridge.Bridge to get all known, possible protocols.

    See Also:
        `API BridgeFactory <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1bridge_1_1BridgeFactory.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sheet
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .solver_constraint import SolverConstraint as SolverConstraint_f1e30dc1
    from .x_spreadsheet_document import XSpreadsheetDocument as XSpreadsheetDocument_2a1f0f30
    from ..table.cell_address import CellAddress as CellAddress_ae5f0b56

class XSolver(XInterface_8f010a43):
    """
    allows to call a solver for a model that is defined by spreadsheet cells.

    See Also:
        `API XSolver <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sheet_1_1XSolver.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.sheet.XSolver']

    def solve(self) -> None:
        """
        executes the calculation and tries to find a solution.
        """
    @property
    def Constraints(self) -> 'typing.Tuple[SolverConstraint_f1e30dc1, ...]':
        """
        The constraints of the model.
        """

    @property
    def Solution(self) -> 'typing.Tuple[float, ...]':
        """
        contains the solution's value for each of the variables, if a solution was found.
        """

    @property
    def Variables(self) -> 'typing.Tuple[CellAddress_ae5f0b56, ...]':
        """
        The addresses of the cells that contain the variables.
        """

    @property
    def Document(self) -> 'XSpreadsheetDocument_2a1f0f30':
        """
        The spreadsheet document that contains the cells.
        """

    @property
    def Maximize(self) -> bool:
        """
        selects if the objective value is maximized or minimized.
        """

    @property
    def Objective(self) -> 'CellAddress_ae5f0b56':
        """
        The address of the cell that contains the objective value.
        """

    @property
    def ResultValue(self) -> float:
        """
        contains the objective value for the solution, if a solution was found.
        """

    @property
    def Success(self) -> bool:
        """
        contains TRUE if a solution was found.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.awt
from typing_extensions import Literal
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XDialog(XInterface_8f010a43):
    """
    makes it possible to show and hide a dialog and gives access to the title of the dialog.

    See Also:
        `API XDialog <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XDialog.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.awt.XDialog']

    def endExecute(self) -> None:
        """
        hides the dialog and then causes XDialog.execute() to return.
        """
    def execute(self) -> int:
        """
        runs the dialog modally: shows it, and waits for the execution to end.
        
        Returns an exit code (e.g., indicating the button that was used to end the execution).
        """
    def getTitle(self) -> str:
        """
        gets the title of the dialog.
        """
    def setTitle(self, Title: str) -> None:
        """
        sets the title of the dialog.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.io
from typing_extensions import Literal
from .x_output_stream import XOutputStream as XOutputStream_a4e00b35

class XDataOutputStream(XOutputStream_a4e00b35):
    """
    makes it possible to write machine-independent simple data types to a stream.

    See Also:
        `API XDataOutputStream <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1io_1_1XDataOutputStream.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.io.XDataOutputStream']

    def writeBoolean(self, Value: bool) -> None:
        """
        writes a boolean.
        
        It is an 8-bit value. 0 means FALSE; all other values mean TRUE.

        Raises:
            com.sun.star.io.IOException: ``IOException``
        """
    def writeByte(self, Value: int) -> None:
        """
        writes an 8-bit byte.

        Raises:
            com.sun.star.io.IOException: ``IOException``
        """
    def writeChar(self, Value: str) -> None:
        """
        writes a 16-bit character.

        Raises:
            com.sun.star.io.IOException: ``IOException``
        """
    def writeDouble(self, Value: float) -> None:
        """
        writes a 64-bit IEEE double.

        Raises:
            com.sun.star.io.IOException: ``IOException``
        """
    def writeFloat(self, Value: float) -> None:
        """
        writes a 32-bit IEEE float.

        Raises:
            com.sun.star.io.IOException: ``IOException``
        """
    def writeHyper(self, Value: int) -> None:
        """
        writes a 64-bit big endian integer.

        Raises:
            com.sun.star.io.IOException: ``IOException``
        """
    def writeLong(self, Value: int) -> None:
        """
        writes a 32-bit big endian integer.

        Raises:
            com.sun.star.io.IOException: ``IOException``
        """
    def writeShort(self, Value: int) -> None:
        """
        writes a 16-bit big endian integer.

        Raises:
            com.sun.star.io.IOException: ``IOException``
        """
    def writeUTF(self, Value: str) -> None:
        """
        writes a string in UTF format.

        Raises:
            com.sun.star.io.IOException: ``IOException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.datatransfer.dnd
from .x_drop_target import XDropTarget as XDropTarget_49e50fbf
from ...lang.x_component import XComponent as XComponent_98dc0ab5
from ...lang.x_initialization import XInitialization as XInitialization_d46c0cca

class OleDropTarget(XDropTarget_49e50fbf, XComponent_98dc0ab5, XInitialization_d46c0cca):
    """
    Service Class

    This service connects the Java-like UNO Drag & Drop protocol to the protocol used on window platforms.
    
    It realizes the drop target.

    See Also:
        `API OleDropTarget <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1datatransfer_1_1dnd_1_1OleDropTarget.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.awt
from typing_extensions import Literal


class VclWindowPeerAttribute(object):
    """
    Const

    specifies attributes for the VCL window implementation.
    
    IMPORTANT: These constants have to be disjunct with constants in WindowAttribute.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API VclWindowPeerAttribute <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1awt_1_1VclWindowPeerAttribute.html>`_
    """
    HSCROLL: Literal[256]
    VSCROLL: Literal[512]
    LEFT: Literal[1024]
    CENTER: Literal[2048]
    RIGHT: Literal[4096]
    SPIN: Literal[8192]
    SORT: Literal[16384]
    DROPDOWN: Literal[32768]
    DEFBUTTON: Literal[65536]
    READONLY: Literal[262144]
    CLIPCHILDREN: Literal[524288]
    NOBORDER: Literal[1048576]
    GROUP: Literal[2097152]
    OK: Literal[4194304]
    OK_CANCEL: Literal[8388608]
    YES_NO: Literal[16777216]
    YES_NO_CANCEL: Literal[33554432]
    RETRY_CANCEL: Literal[67108864]
    DEF_OK: Literal[134217728]
    DEF_CANCEL: Literal[268435456]
    DEF_RETRY: Literal[536870912]
    DEF_YES: Literal[1073741824]
    DEF_NO: Literal[-2147483648]
    NOLABEL: Literal[536870912]
    AUTOHSCROLL: Literal[1073741824]
    AUTOVSCROLL: Literal[-2147483648]




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.bridge.oleautomation
from ...lang.x_multi_service_factory import XMultiServiceFactory as XMultiServiceFactory_191e0eb6

class Factory(XMultiServiceFactory_191e0eb6):
    """
    Service Class

    makes it possible to create COM objects as UNO objects.
    
    A COM object must have a ProgId since the ProgId is used as argument for com.sun.star.lang.XMultiServiceFactory.createInstance(). The only interfaces which are mapped are IUnknown and IDispatch. The created UNO objects support com.sun.star.script.XInvocation if the original COM objects support IDispatch.
    
    The optional parameters of the method com.sun.star.lang.XMultiServiceFactory.createInstanceWithArguments() are reserved for future use; at this time they are ignored.

    See Also:
        `API Factory <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1bridge_1_1oleautomation_1_1Factory.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.ui.test
from typing_extensions import Literal
import typing
from abc import ABC
if typing.TYPE_CHECKING:
    from ...beans.property_values import PropertyValues as PropertyValues_d6470ce6
    from .xui_object import XUIObject as XUIObject_ad8a0b21

class XUITest(ABC):
    """

    See Also:
        `API XUITest <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ui_1_1test_1_1XUITest.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.ui.test.XUITest']

    def executeCommand(self, command: str) -> bool:
        """
        """
    def executeCommandWithParameters(self, command: str, propValues: 'PropertyValues_d6470ce6') -> bool:
        """
        """
    def executeDialog(self, command: str) -> bool:
        """
        """
    def getFloatWindow(self) -> 'XUIObject_ad8a0b21':
        """
        """
    def getTopFocusWindow(self) -> 'XUIObject_ad8a0b21':
        """
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.chart2
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing


class DataPointLabel(object):
    """
    Struct Class

    
    **since**
    
        LibreOffice 7.1

    See Also:
        `API DataPointLabel <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1chart2_1_1DataPointLabel.html>`_
    """
    typeName: Literal['com.sun.star.chart2.DataPointLabel']

    def __init__(self, ShowNumber: typing.Optional[bool] = ..., ShowNumberInPercent: typing.Optional[bool] = ..., ShowCategoryName: typing.Optional[bool] = ..., ShowLegendSymbol: typing.Optional[bool] = ..., ShowCustomLabel: typing.Optional[bool] = ..., ShowSeriesName: typing.Optional[bool] = ...) -> None:
        """
        Constructor

        Arguments:
            ShowNumber (bool, optional): ShowNumber value.
            ShowNumberInPercent (bool, optional): ShowNumberInPercent value.
            ShowCategoryName (bool, optional): ShowCategoryName value.
            ShowLegendSymbol (bool, optional): ShowLegendSymbol value.
            ShowCustomLabel (bool, optional): ShowCustomLabel value.
            ShowSeriesName (bool, optional): ShowSeriesName value.
        """


    @property
    def ShowNumber(self) -> bool:
        """
        if TRUE, the value that is represented by a data point is displayed next to it.
        """


    @property
    def ShowNumberInPercent(self) -> bool:
        """
        This is only effective, if ShowNumber is TRUE.
        
        If this member is also TRUE, the numbers are displayed as percentages of a category.
        
        That means, if a data point is the first one of a series, the percentage is calculated by using the first data points of all available series.
        """


    @property
    def ShowCategoryName(self) -> bool:
        """
        The caption contains the category name of the category to which a data point belongs.
        """


    @property
    def ShowLegendSymbol(self) -> bool:
        """
        The symbol of data series is additionally displayed in the caption.
        """


    @property
    def ShowCustomLabel(self) -> bool:
        """
        The caption contains a custom label text, which belongs to a data point label.
        
        **since**
        
            LibreOffice 7.1
        """


    @property
    def ShowSeriesName(self) -> bool:
        """
        The name of the data series is additionally displayed in the caption.
        
        **since**
        
            LibreOffice 7.2
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Exception Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.java
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing
from .java_initialization_exception import JavaInitializationException as JavaInitializationException_8b6211a3
from ..uno.x_interface import XInterface as XInterface_8f010a43

class JavaDisabledException(JavaInitializationException_8b6211a3):
    """
    Exception Class

    indicates that Java could not be initialized because it has been switched off.
    
    The user has switched off Java in the configuration of the office, for example by means of the options dialog.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API JavaDisabledException <https://api.libreoffice.org/docs/idl/ref/exceptioncom_1_1sun_1_1star_1_1java_1_1JavaDisabledException.html>`_
    """

    typeName: Literal['com.sun.star.java.JavaDisabledException']

    def __init__(self, Message: typing.Optional[str] = ..., Context: typing.Optional[XInterface_8f010a43] = ...) -> None:
        """
        Constructor

        Arguments:
            Message (str, optional): Message value.
            Context (XInterface, optional): Context value.
        """

__all__ = ['JavaDisabledException']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.io
from .x_active_data_sink import XActiveDataSink as XActiveDataSink_b8d00ba3
from .x_connectable import XConnectable as XConnectable_980a0a96
from .x_input_stream import XInputStream as XInputStream_98d40ab4
from .x_markable_stream import XMarkableStream as XMarkableStream_b9bc0bc3

class MarkableInputStream(XActiveDataSink_b8d00ba3, XConnectable_980a0a96, XInputStream_98d40ab4, XMarkableStream_b9bc0bc3):
    """
    Service Class

    allows to set marks in an inputstream and to later jump back to these marks.
    
    The implementation reads the original data from the input stream, that has been set previously at the XActiveDataSink interface. In general the implementation must buffer the data.

    See Also:
        `API MarkableInputStream <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1io_1_1MarkableInputStream.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sdbcx
from typing_extensions import Literal
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XAuthorizable(XInterface_8f010a43):
    """
    is used for accessing and setting the permissions of a user for a database object.

    See Also:
        `API XAuthorizable <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdbcx_1_1XAuthorizable.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.sdbcx.XAuthorizable']

    def getGrantablePrivileges(self, objName: str, objType: int) -> int:
        """
        retrieves the permissions for a specific object, which could be granted to other users and groups.

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
    def getPrivileges(self, objName: str, objType: int) -> int:
        """
        retrieves the permissions for a specific object.

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
    def grantPrivileges(self, objName: str, objType: int, objPrivileges: int) -> None:
        """
        adds additional permissions for a specific object.

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
    def revokePrivileges(self, objName: str, objType: int, objPrivileges: int) -> None:
        """
        removes permissions for a specific object from a group or user.

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.table
# Libre Office Version: 7.3
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    import uno
"""
Enum



See Also:
    `API CellVertJustify <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1table.html#a17834bec5bf9ac4432141dee1c03b50b>`_
"""

BOTTOM: 'uno.Enum'
"""
contents are aligned to the lower edge of the cell.
"""
CENTER: 'uno.Enum'
"""
contents are horizontally centered.

contents are aligned to the vertical middle of the cell.
"""
STANDARD: 'uno.Enum'
"""
default alignment is used (left for numbers, right for text).

default alignment is used.

contents are printed from left to right.
"""
TOP: 'uno.Enum'
"""
contents are aligned with the upper edge of the cell.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.presentation
from typing_extensions import Literal
"""
Const

This constants defines a type for an animation effect node.

This is stored with the name node-type inside the com.sun.star.animations.XAnimationNode.UserData sequence.
This does not manipulate the timing or synchronization. It can be used to quickly identify semantic blocks inside an animation hierarchy.

See Also:
    `API EffectNodeType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1presentation_1_1EffectNodeType.html>`_
"""
DEFAULT: Literal[0]
"""
This node has no special meaning.
"""
ON_CLICK: Literal[1]
"""
This node contains an effect that starts on click.
"""
WITH_PREVIOUS: Literal[2]
"""
This node contains an effect that starts with a previous effect.
"""
AFTER_PREVIOUS: Literal[3]
"""
This node contains an effect that starts after a previous effect has finished.
"""
MAIN_SEQUENCE: Literal[4]
"""
This is the main sequence for effects that is automatically started.
"""
TIMING_ROOT: Literal[5]
"""
This is the root sequence.
"""
INTERACTIVE_SEQUENCE: Literal[6]
"""
This is a sequence with effects that starts due to user interaction.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.embed
from typing_extensions import Literal


class EmbedMapUnits(object):
    """
    Const

    contains list of possible map modes supported by embedded object.

    See Also:
        `API EmbedMapUnits <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1embed_1_1EmbedMapUnits.html>`_
    """
    ONE_100TH_MM: Literal[0]
    """
    In this type of map mode one logical point is equal to one-hundredth of millimeter.
    """
    ONE_10TH_MM: Literal[1]
    """
    In this type of map mode one logical point is equal to one-tenth of millimeter.
    """
    ONE_MM: Literal[2]
    """
    In this type of map mode one logical point is equal to one millimeter.
    """
    ONE_CM: Literal[3]
    """
    In this type of map mode one logical point is equal to one centimeter.
    """
    ONE_1000TH_INCH: Literal[4]
    """
    In this type of map mode one logical point is equal to one-thousandth of inch.
    """
    ONE_100TH_INCH: Literal[5]
    """
    In this type of map mode one logical point is equal to one-hundredth of inch.
    """
    ONE_10TH_INCH: Literal[6]
    """
    In this type of map mode one logical point is equal to one-tenth of inch.
    """
    ONE_INCH: Literal[7]
    """
    In this type of map mode one logical point is equal to one inch.
    """
    POINT: Literal[8]
    """
    In this type of map mode one logical point is equal to one typographical point.
    """
    TWIP: Literal[9]
    """
    In this type of map mode one logical point is equal to one twentieth of typographical point.
    """
    PIXEL: Literal[10]
    """
    In this type of map mode one logical point is equal to one pixel.
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing
from .rule import Rule as Rule_571307da


class RuleSet(object):
    """
    Struct Class

    describes a set of Rules.
    
    A RuleSet is applied to a folder. It consists of a sequence of rules. Each rule consists of a sequence of RuleTerms describing the objects to which the rule should by applied and the RuleAction which should be performed on the matching objects.

    See Also:
        `API RuleSet <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1ucb_1_1RuleSet.html>`_
    """
    typeName: Literal['com.sun.star.ucb.RuleSet']

    def __init__(self, Rules: typing.Optional[typing.Tuple[Rule_571307da, ...]] = ..., HandleFolder: typing.Optional[bool] = ...) -> None:
        """
        Constructor

        Arguments:
            Rules (typing.Tuple[Rule, ...], optional): Rules value.
            HandleFolder (bool, optional): HandleFolder value.
        """


    @property
    def Rules(self) -> typing.Tuple[Rule_571307da, ...]:
        """
        contains a number of rules.
        """


    @property
    def HandleFolder(self) -> bool:
        """
        is a flag indicating whether the rules apply to folders, too.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.text
from typing_extensions import Literal
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XTextTableCursor(XInterface_8f010a43):
    """
    The TextTableCursor provide methods to navigate through the table structure, to merge and split cells.

    See Also:
        `API XTextTableCursor <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1text_1_1XTextTableCursor.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.text.XTextTableCursor']

    def getRangeName(self) -> str:
        """
        The name is the cell name of the top left table cell of the range concatenated by \":\" with the table cell name of the bottom left table cell of the cell range. If the range consists of one table cell only then the name of that table cell is returned.
        """
    def goDown(self, nCount: int, bExpand: bool) -> bool:
        """
        moves the cursor to the bottom neighbor cell.
        """
    def goLeft(self, nCount: int, bExpand: bool) -> bool:
        """
        moves the cursor to the left neighbor.
        """
    def goRight(self, nCount: int, bExpand: bool) -> bool:
        """
        moves the cursor to the right neighbor.
        """
    def goUp(self, nCount: int, bExpand: bool) -> bool:
        """
        moves the cursor to the top neighbor.
        """
    def gotoCellByName(self, aCellName: str, bExpand: bool) -> bool:
        """
        moves the cursor to the cell with the specified name.
        """
    def gotoEnd(self, bExpand: bool) -> None:
        """
        moves the cursor to the bottom right cell of the table.
        """
    def gotoStart(self, bExpand: bool) -> None:
        """
        moves the cursor to the top left cell of the table.
        """
    def mergeRange(self) -> bool:
        """
        merges the selected range of cells.
        """
    def splitRange(self, nCount: int, bHorizontal: bool) -> bool:
        """
        splits the range of cells.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.datatransfer.dnd
# Libre Office Version: 7.3
from typing_extensions import Literal
from .drop_target_event import DropTargetEvent as DropTargetEvent_8d651169
from ...uno.x_interface import XInterface as XInterface_8f010a43
import typing
from .x_drop_target_drag_context import XDropTargetDragContext as XDropTargetDragContext_10221422


class DropTargetDragEvent(DropTargetEvent_8d651169):
    """
    Struct Class

    The DropTargetDragEvent is delivered from the drop target to the currently registered drop target listener.
    
    It contains information regarding the current state of the operation to enable the operations initiator to provide the end user with the appropriate drag over feedback.

    See Also:
        `API DropTargetDragEvent <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1datatransfer_1_1dnd_1_1DropTargetDragEvent.html>`_
    """
    typeName: Literal['com.sun.star.datatransfer.dnd.DropTargetDragEvent']

    def __init__(self, Source: typing.Optional[XInterface_8f010a43] = ..., Dummy: typing.Optional[int] = ..., Context: typing.Optional[XDropTargetDragContext_10221422] = ..., DropAction: typing.Optional[int] = ..., LocationX: typing.Optional[int] = ..., LocationY: typing.Optional[int] = ..., SourceActions: typing.Optional[int] = ...) -> None:
        """
        Constructor

        Arguments:
            Source (XInterface, optional): Source value.
            Dummy (int, optional): Dummy value.
            Context (XDropTargetDragContext, optional): Context value.
            DropAction (int, optional): DropAction value.
            LocationX (int, optional): LocationX value.
            LocationY (int, optional): LocationY value.
            SourceActions (int, optional): SourceActions value.
        """


    @property
    def Context(self) -> XDropTargetDragContext_10221422:
        """
        The drop target context of the current drag operation.
        """


    @property
    def DropAction(self) -> int:
        """
        This value represents the currently selected drop action.
        """


    @property
    def LocationX(self) -> int:
        """
        The cursor's current x location within the window's coordinates.
        """


    @property
    def LocationY(self) -> int:
        """
        The cursor's current y location within the window's coordinates.
        """


    @property
    def SourceActions(self) -> int:
        """
        This value represents the action or actions supported by the source.
        
        This may be a combination of arbitrary source actions except ACTION_DEFAULT.
        
        To combine different actions use a logical OR.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.form.component
import typing
from ..form_control_model import FormControlModel as FormControlModel_e2990d22
if typing.TYPE_CHECKING:
    from ...awt.font_descriptor import FontDescriptor as FontDescriptor_bc110c0a

class NavigationToolBar(FormControlModel_e2990d22):
    """
    Service Class

    This service specifies the model for control which provides controller functionality for a DataForm, such as navigating or filtering the form.

    See Also:
        `API NavigationToolBar <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1form_1_1component_1_1NavigationToolBar.html>`_
    """
    @property
    def Border(self) -> int:
        """
        denotes the border style of the control.
        
        Allowed values are
        """
    @property
    def Enabled(self) -> bool:
        """
        determines whether the control is enabled or disabled.
        """
    @property
    def FontDescriptor(self) -> 'FontDescriptor_bc110c0a':
        """
        contains the font attributes for the text in the control
        """
    @property
    def FontEmphasisMark(self) -> int:
        """
        specifies the emphasis mark for the font described in FontDescriptor
        
        The value must be one of the com.sun.star.text.FontEmphasis constants.
        """
    @property
    def FontRelief(self) -> int:
        """
        specifies the relief for the font described in FontDescriptor
        
        The value must be one of the com.sun.star.text.FontRelief constants.
        """
    @property
    def IconSize(self) -> int:
        """
        specifies the size of the icons in the control
        
        At least the following values are to be supported:
        """
    @property
    def RepeatDelay(self) -> int:
        """
        specifies a repeat delay for the control
        
        Some buttons of a NavigationToolBar may show repeating behavior, e.g. may be repeatedly triggered when the user keeps the mouse pressed over such a button.
        The delay between two such triggers (in milliseconds) is specified with this property.
        """
    @property
    def ShowFilterSort(self) -> bool:
        """
        determines whether the control should provide functionality for filtering and sorting the parent form
        """
    @property
    def ShowNavigation(self) -> bool:
        """
        determines whether the control should provide functionality for navigating the parent form
        """
    @property
    def ShowPosition(self) -> bool:
        """
        determines whether the control should provide functionality for positioning the parent form
        """
    @property
    def ShowRecordActions(self) -> bool:
        """
        determines whether the control should provide functionality for acting on the current record of the parent form
        """
    @property
    def TextColor(self) -> int:
        """
        specifies the text color (as RGB value) of the control.
        """
    @property
    def TextLineColor(self) -> int:
        """
        specifies the text line color (as RGB value) of the control.
        
        This color is used if the FontDescriptor defines that the text in the control should be underlined or stroke out.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.rdf
from .x_blank_node import XBlankNode as XBlankNode_8cf40a0a

class BlankNode(XBlankNode_8cf40a0a):
    """
    Service Class

    represents a blank node that may occur in a RDF graph.
    
    **since**
    
        OOo 3.0

    See Also:
        `API BlankNode <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1rdf_1_1BlankNode.html>`_
    """
    def create(self, NodeID: str) -> None:
        """
        create a blank RDF node.
        
        Be careful! With this constructor you can create a node that aliases another node that already exists in some repository. That may or may not be what you want. If you want to create a new blank node that is guaranteed to be unique, use XRepository.createBlankNode() instead.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sheet
from typing_extensions import Literal
"""
Const

used to specify a function to be calculated from values.

**since**

    LibreOffice 5.3

See Also:
    `API GeneralFunction2 <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1sheet_1_1GeneralFunction2.html>`_
"""
NONE: Literal[0]
"""
nothing is calculated.
"""
AUTO: Literal[1]
"""
function is determined automatically.

If the values are all numerical, SUM is used, otherwise COUNT.
"""
SUM: Literal[2]
"""
sum of all numerical values is calculated.
"""
COUNT: Literal[3]
"""
all values, including non-numerical values, are counted.
"""
AVERAGE: Literal[4]
"""
average of all numerical values is calculated.
"""
MAX: Literal[5]
"""
maximum value of all numerical values is calculated.
"""
MIN: Literal[6]
"""
minimum value of all numerical values is calculated.
"""
PRODUCT: Literal[7]
"""
product of all numerical values is calculated.
"""
COUNTNUMS: Literal[8]
"""
numerical values are counted.
"""
STDEV: Literal[9]
"""
standard deviation is calculated based on a sample.
"""
STDEVP: Literal[10]
"""
standard deviation is calculated based on the entire population.
"""
VAR: Literal[11]
"""
variance is calculated based on a sample.
"""
VARP: Literal[12]
"""
variance is calculated based on the entire population.
"""
MEDIAN: Literal[13]
"""
median of all numerical values is calculated.

**since**

    LibreOffice 5.3
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.i18n
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .forbidden_characters import ForbiddenCharacters as ForbiddenCharacters_ce0dd5
    from ..lang.locale import Locale as Locale_70d308fa

class XForbiddenCharacters(XInterface_8f010a43):
    """
    provides access to forbidden character settings in a document.
    
    In some languages, particular characters are not allowed to be placed at the beginning or at the end of a text line.

    See Also:
        `API XForbiddenCharacters <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1i18n_1_1XForbiddenCharacters.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.i18n.XForbiddenCharacters']

    def getForbiddenCharacters(self, aLocale: 'Locale_70d308fa') -> 'ForbiddenCharacters_ce0dd5':
        """
        returns the forbidden characters for a given locale.

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """
    def hasForbiddenCharacters(self, aLocale: 'Locale_70d308fa') -> bool:
        """
        determines if forbidden characters are set for a given locale.
        """
    def removeForbiddenCharacters(self, aLocale: 'Locale_70d308fa') -> None:
        """
        removes the setting of forbidden characters for a given locale.
        """
    def setForbiddenCharacters(self, aLocale: 'Locale_70d308fa', aForbiddenCharacters: 'ForbiddenCharacters_ce0dd5') -> None:
        """
        sets the forbidden characters for a given Locale.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Singleton Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ui
# Libre Office Version: 7.3
from ..container.x_name_access import XNameAccess as XNameAccess_e2ab0cf6


class theUICategoryDescription(XNameAccess_e2ab0cf6):
    """
    Singleton Class

    a singleton which provides information about user interface command categories.
    
    OpenOffice.org has an amount of commands that can be used by user interface elements. Every command is member of a single category. Categories makes it easier to handle to huge amount of commands provided by OpenOffice.org. This singleton is normally used by UI implementations which provides all commands to a user.
    
    Provides access to user interface command categories of the installed modules.
    
    To access the user interface command categories of a module, a unique module specifier must be provided to com.sun.star.container.XNameAccess.getByName() function. The module specifier can be retrieved from the com.sun.star.frame.ModuleManager service. The interface provides references to com.sun:star.ui.ModuleUICommandDescription.
    
    Prior to LibreOffice 4.3, this singleton was only available as a (single-instance) UICategoryDescription service.
    
    **since**
    
        LibreOffice 4.3

    See Also:
        `API theUICategoryDescription <https://api.libreoffice.org/docs/idl/ref/singletoncom_1_1sun_1_1star_1_1ui_1_1theUICategoryDescription.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.awt
from .uno_control_dialog_element import UnoControlDialogElement as UnoControlDialogElement_38ef0f81
from .x_control_model import XControlModel as XControlModel_affc0b7e
from ..beans.x_multi_property_set import XMultiPropertySet as XMultiPropertySet_fd880e05
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from ..io.x_persist_object import XPersistObject as XPersistObject_af2f0b79
from ..lang.x_component import XComponent as XComponent_98dc0ab5
from ..util.x_cloneable import XCloneable as XCloneable_99d00aa3

class UnoControlModel(UnoControlDialogElement_38ef0f81, XControlModel_affc0b7e, XMultiPropertySet_fd880e05, XPropertySet_bc180bfa, XPersistObject_af2f0b79, XComponent_98dc0ab5, XCloneable_99d00aa3):
    """
    Service Class

    specifies the standard model of a UnoControl in the Smalltalk model view controller design.
    
    The interfaces com.sun.star.beans.XPropertySet and com.sun.star.beans.XMultiPropertySet need access to the model data from the embedding environment. The control and the model can specify additional interfaces to exchange data or export more functionality from the model.

    See Also:
        `API UnoControlModel <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlModel.html>`_
    """
    @property
    def DefaultControl(self) -> str:
        """
        specifies the service name of the default control for this model.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.text
from typing_extensions import Literal
"""
Const

These enumeration values are used to specify the vertical orientation.

See Also:
    `API VertOrientation <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1text_1_1VertOrientation.html>`_
"""
NONE: Literal[0]
"""
no hard alignment
"""
TOP: Literal[1]
"""
aligned at the top
"""
CENTER: Literal[2]
"""
aligned at the center
"""
BOTTOM: Literal[3]
"""
aligned at the bottom
"""
CHAR_TOP: Literal[4]
"""
aligned at the top of a character (anchored to character)
"""
CHAR_CENTER: Literal[5]
"""
aligned at the center of a character (anchored to character )
"""
CHAR_BOTTOM: Literal[6]
"""
aligned at the bottom of a character (anchored to character )
"""
LINE_TOP: Literal[7]
"""
aligned at the top of the line (anchored to character )
"""
LINE_CENTER: Literal[8]
"""
aligned at the center of the line (anchored to character )
"""
LINE_BOTTOM: Literal[9]
"""
aligned at the bottom of the line (anchored to character )
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Exception Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.configuration.backend
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing
from ...uno.exception import Exception as Exception_85530a09
from ...uno.x_interface import XInterface as XInterface_8f010a43

class MalformedDataException(Exception_85530a09):
    """
    Exception Class

    is raised when the data of a component schema, layer or update is not well-formed, violates the schema or is otherwise invalid.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API MalformedDataException <https://api.libreoffice.org/docs/idl/ref/exceptioncom_1_1sun_1_1star_1_1configuration_1_1backend_1_1MalformedDataException.html>`_
    """

    typeName: Literal['com.sun.star.configuration.backend.MalformedDataException']

    def __init__(self, Message: typing.Optional[str] = ..., Context: typing.Optional[XInterface_8f010a43] = ..., ErrorDetails: typing.Optional[object] = ...) -> None:
        """
        Constructor

        Arguments:
            Message (str, optional): Message value.
            Context (XInterface, optional): Context value.
            ErrorDetails (object, optional): ErrorDetails value.
        """
    @property
    def ErrorDetails(self) -> object:
        """
        data that provides more detailed information about the reason and location of the error.
        
        Typically this member should contain an exception characterizing the error in detail.
        
        For example the following exceptions may be used:
        
        If no more detail information is available, this may be left VOID.
        """


__all__ = ['MalformedDataException']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Exception Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.util
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing
from ..uno.exception import Exception as Exception_85530a09
from ..uno.x_interface import XInterface as XInterface_8f010a43

class InvalidStateException(Exception_85530a09):
    """
    Exception Class

    is thrown when an object's state does not allow to call requested functionality.

    See Also:
        `API InvalidStateException <https://api.libreoffice.org/docs/idl/ref/exceptioncom_1_1sun_1_1star_1_1util_1_1InvalidStateException.html>`_
    """

    typeName: Literal['com.sun.star.util.InvalidStateException']

    def __init__(self, Message: typing.Optional[str] = ..., Context: typing.Optional[XInterface_8f010a43] = ...) -> None:
        """
        Constructor

        Arguments:
            Message (str, optional): Message value.
            Context (XInterface, optional): Context value.
        """

__all__ = ['InvalidStateException']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.frame
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing
from ..beans.named_value import NamedValue as NamedValue_a37a0af3


class ControlCommand(object):
    """
    Struct Class

    describes a command which can be send to a generic toolbar control.
    
    **since**
    
        OOo 2.0.3

    See Also:
        `API ControlCommand <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1frame_1_1ControlCommand.html>`_
    """
    typeName: Literal['com.sun.star.frame.ControlCommand']

    def __init__(self, Arguments: typing.Optional[typing.Tuple[NamedValue_a37a0af3, ...]] = ..., Command: typing.Optional[str] = ...) -> None:
        """
        Constructor

        Arguments:
            Arguments (typing.Tuple[NamedValue, ...], optional): Arguments value.
            Command (str, optional): Command value.
        """


    @property
    def Arguments(self) -> typing.Tuple[NamedValue_a37a0af3, ...]:
        """
        specifies a sequence of named values which are used as argument for the command.
        
        The number and type of arguments depend on the command and control.
        """


    @property
    def Command(self) -> str:
        """
        specifies the command which should be processed by the toolbar control.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.configuration
from .hierarchy_access import HierarchyAccess as HierarchyAccess_5e871071
from .simple_set_access import SimpleSetAccess as SimpleSetAccess_5ea81068

class SetAccess(HierarchyAccess_5e871071, SimpleSetAccess_5ea81068):
    """
    Service Class

    provides access to a dynamic, homogeneous set of values or nested trees within a hierarchy.
    
    Also provides information about the template for elements. Allows normalizing externally generated names.
    
    Sets are dynamic containers within the hierarchy.
    
    The number and names of contained elements are not fixed in advance, but all elements have to be of one predetermined type.

    See Also:
        `API SetAccess <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1configuration_1_1SetAccess.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.chart
from typing_extensions import Literal
"""
Const

These values specify how the captions of data points are displayed.

**since**

    LibreOffice 7.1

See Also:
    `API ChartDataCaption <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1chart_1_1ChartDataCaption.html>`_
"""
NONE: Literal[0]
"""
No captions are displayed.
"""
VALUE: Literal[1]
"""
The caption contains the value of the data point in the number format of the axis that is attached to the respective data series.
"""
PERCENT: Literal[2]
"""
The caption contains the value of the data point in percent of all data points of one category.

That means, if a data point is the first one of a series, the percentage is calculated by using the first data points of all available series.
"""
TEXT: Literal[4]
"""
The caption contains the category name of the category to which a data point belongs.
"""
FORMAT: Literal[8]
"""
The number formatter is always used for displaying the value as value.

So this setting is deprecated.
"""
SYMBOL: Literal[16]
"""
The symbol of data column/row is additionally displayed in the caption.
"""
CUSTOM: Literal[32]
"""
The caption contains a custom text, which belongs to a data point label.

**since**

    LibreOffice 7.1
"""
DATA_SERIES: Literal[64]
"""
The name of the data series is additionally displayed in the caption.

**since**

    LibreOffice 7.2
"""

